###################################################
### chunk number 1: 
###################################################
options(width=75, prompt="R> ")
library("simFrame")
set.seed(1234)


###################################################
### chunk number 2: 
###################################################
showMethods("setNA")


###################################################
### chunk number 3: 
###################################################
nc <- NAControl(NArate = 0.05)
getNArate(nc)
setNArate(nc, c(0.01, 0.03, 0.05, 0.07, 0.09))
getNArate(nc)


###################################################
### chunk number 4: 
###################################################
library("mvtnorm")
dc <- DataControl(size = 10, distribution = rmvnorm, dots = 
    list(mean = rep(0, 2), sigma = matrix(c(1, 0.5, 0.5, 1), 2, 2)))


###################################################
### chunk number 5: 
###################################################
foo <- generate(dc)
foo


###################################################
### chunk number 6: 
###################################################
data("eusilcP")
set <- setup(eusilcP, size = 10, k = 2)
summary(set)
set
draw(eusilcP[, c("id", "eqIncome")], set, i = 1)


###################################################
### chunk number 7: 
###################################################
cc <- DARContControl(target = "V2", epsilon = 0.2, 
    fun = function(x) x * 100)


###################################################
### chunk number 8: 
###################################################
bar <- contaminate(foo, cc)
bar


###################################################
### chunk number 9: 
###################################################
nc <- NAControl(NArate = 0.3)


###################################################
### chunk number 10: 
###################################################
setNA(bar, nc)


###################################################
### chunk number 11: 
###################################################
data("eusilcP")
sc <- SampleControl(size = 500, k = 50)
cc <- DARContControl(target = "eqIncome", epsilon = 0.02, 
    fun = function(x) x * 25)
sim <- function(x) {
    c(mean = mean(x$eqIncome), trimmed = mean(x$eqIncome, trim = 0.02))
}
set.seed(12345)
results <- runSimulation(eusilcP, sc, contControl = cc, fun = sim)


###################################################
### chunk number 12: 
###################################################
head(results)
aggregate(results)
tv <- mean(eusilcP$eqIncome)
tv


###################################################
### chunk number 13: 
###################################################
print(plot(results, true = tv))


###################################################
### chunk number 14: 
###################################################
print(simDensityplot(results, true = tv))


###################################################
### chunk number 15: 
###################################################
library("laeken")
data("eusilcP")
set.seed(12345)


###################################################
### chunk number 16: 
###################################################
set <- setup(eusilcP, design = "region", grouping = "hid", 
    size = c(75, 250, 250, 125, 200, 225, 125, 150, 100), k = 100)
#    size = c(75, 250, 250, 125, 200, 225, 125, 150, 100), k=3)


###################################################
### chunk number 17: 
###################################################
cc <- DCARContControl(target = "eqIncome", epsilon = 0.005, 
    grouping = "hid", dots = list(mean = 500000, sd = 10000))


###################################################
### chunk number 18: 
###################################################
sim <- function(x, k) {
    g <- gini(x$eqIncome, x$.weight)$value
    eqIncHill <- fitPareto(x$eqIncome, k = k, 
        method = "thetaHill", groups = x$hid)
    gHill <- gini(eqIncHill, x$.weight)$value
    eqIncPDC <- fitPareto(x$eqIncome, k = k, 
        method = "thetaPDC", groups = x$hid)
    gPDC <- gini(eqIncPDC, x$.weight)$value
    c(standard = g, Hill = gHill, PDC = gPDC)
}


###################################################
### chunk number 19: 
###################################################
results <- runSimulation(eusilcP, set, contControl = cc, 
    design = "gender", fun = sim, k = 125)


###################################################
### chunk number 20: 
###################################################
head(results)
aggregate(results)


###################################################
### chunk number 21: 
###################################################
tv <- simSapply(eusilcP, "gender", function(x) gini(x$eqIncome)$value)


###################################################
### chunk number 22: 
###################################################
print(plot(results, true = tv, xlab = "Gini coefficient"))


###################################################
### chunk number 23: 
###################################################
library("robCompositions")
library("mvtnorm")
set.seed(12345)


###################################################
### chunk number 24: 
###################################################
crnorm <- function(n, mean, sigma) invilr(rmvnorm(n, mean, sigma))
sigma <- matrix(c(1, -0.5, 1.4, -0.5, 1, -0.6, 1.4, -0.6, 2), 3, 3)
dc <- DataControl(size = 150, distribution = crnorm, 
    dots = list(mean = c(0, 2, 3), sigma = sigma))


###################################################
### chunk number 25: 
###################################################
nc <- NAControl(NArate = 0.05)


###################################################
### chunk number 26: 
###################################################
sim <- function(x, orig) {
    i <- apply(x, 1, function(x) any(is.na(x)))
    ni <- length(which(i))
    xKNNa <- impKNNa(x)$xImp
    xLS <- impCoda(x, method = "lm")$xImp
    c(knn = aDist(xKNNa, orig)/ni, LS = aDist(xLS, orig)/ni)
}


###################################################
### chunk number 27: 
###################################################
results <- runSimulation(dc, nrep = 50, NAControl = nc, fun = sim)
#results <- runSimulation(dc, nrep = 6, NAControl = nc, fun = sim)


###################################################
### chunk number 28: 
###################################################
head(results)
aggregate(results)


###################################################
### chunk number 29: 
###################################################
print(plot(results, xlab = "Relative Aitchison distance"))


###################################################
### chunk number 30: 
###################################################
alpha <- if(names(dev.cur()) == "pdf") 0.6 else 1
print(simDensityplot(results, alpha = alpha, xlab = "Relative Aitchison distance"))


###################################################
### chunk number 31: 
###################################################
cl <- makeCluster(4, type="SOCK")


###################################################
### chunk number 32: 
###################################################
clusterEvalQ(cl, {
        library("simFrame")
        library("robCompositions")
        library("mvtnorm")
    })


###################################################
### chunk number 33: 
###################################################
clusterSetupRNG(cl, seed=12345)


###################################################
### chunk number 34: 
###################################################
crnorm <- function(n, mean, sigma) invilr(rmvnorm(n, mean, sigma))
sigma <- matrix(c(1, -0.5, 1.4, -0.5, 1, -0.6, 1.4, -0.6, 2), 3, 3)
dc <- DataControl(size = 150, distribution = crnorm, 
    dots = list(mean = c(0, 2, 3), sigma = sigma))
nc <- NAControl(NArate = c(0.01, 0.03, 0.05, 0.07, 0.09))
sim <- function(x, orig) {
    i <- apply(x, 1, function(x) any(is.na(x)))
    ni <- length(which(i))
    xKNNa <- impKNNa(x)$xImp
    xLS <- impCoda(x, method = "lm")$xImp
    c(knn = aDist(xKNNa, orig)/ni, LS = aDist(xLS, orig)/ni)
}


###################################################
### chunk number 35: 
###################################################
clusterExport(cl, c("crnorm", "sigma", "dc", "nc", "sim"))


###################################################
### chunk number 36: 
###################################################
results <- clusterRunSimulation(cl, dc, nrep = 50, NAControl = nc, fun = sim)
#results <- clusterRunSimulation(cl, dc, nrep = 2, NAControl = nc, fun = sim)


###################################################
### chunk number 37: 
###################################################
stopCluster(cl)


###################################################
### chunk number 38: 
###################################################
head(results)
aggregate(results)


###################################################
### chunk number 39: 
###################################################
print(plot(results, ylab = "Relative Aitchison distance"))


###################################################
### chunk number 40: 
###################################################
alpha <- if(names(dev.cur()) == "pdf") 0.6 else 1
print(simDensityplot(results, NArate=0.07, 
        alpha = alpha, xlab = "Relative Aitchison distance"))


